<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}论文被引画像🦞{% endblock %}</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.0/font/bootstrap-icons.css" rel="stylesheet">
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <link href="/static/css/style.css" rel="stylesheet">
</head>
<body>
    <nav class="agent-navbar">
        <div class="agent-navbar-inner">
            <a href="/" class="agent-brand">
                <div class="agent-brand-icon">
                    <img src="/static/citationclaw_icon.png" width="28" height="28" alt="CitationClaw" style="border-radius:4px;display:block">
                </div>
                <div>
                    <div class="agent-brand-name">论文被引画像🦞</div>
                    <div class="agent-brand-sub">Citation Intelligence Agent</div>
                </div>
            </a>
            <div class="agent-nav-links">
                <a href="#" class="agent-nav-link" data-spa-panel="home">
                    <i class="bi bi-house-fill"></i> 首页
                </a>
                <a href="#" class="agent-nav-link" data-spa-panel="results">
                    <i class="bi bi-folder2-open"></i> 结果
                </a>
            </div>
        </div>
    </nav>

    <div class="agent-page-content">
        {% block content %}{% endblock %}
    </div>

    <footer class="agent-footer">
        <small>论文被引画像🦞 &nbsp;·&nbsp; 上海交通大学 VisionXLab@RethinkLab</small>
    </footer>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    {% block scripts %}{% endblock %}
</body>
</html>
